@@ -1,7 +1,9 @@
 import numpy as np
 import numba
 from numba import jit
+import re
 import h5py
+import os
 from matplotlib import pyplot as plt
 import nibabel as nib
 from pathlib import Path
@@ -91,4 +93,31 @@ class DatasetManager:
                 download_file.write(container_client.download_blob(uri_base+"_mprage.nii").readall())
             return self.loadDataset(subject, scanner, set)
 
+    def pushDatasetToAzure(self, containerName, subject, scanner, set, regex):
+        if(self.connectionString == None):
+            print("Dataset Manager Azure connection string not set.")
+            return None
+        else:
+            blob_service_client = BlobServiceClient.from_connection_string(self.connectionString)
+            container_name = containerName
+            container_client = blob_service_client.get_container_client(container_name)
+            uri_base = subject+"/"+scanner
+            path_dir = self.localDataRootDir+"/"+subject+"/"+scanner
+            Path(path_dir).mkdir( parents=True, exist_ok=True )
+            container_client = blob_service_client.get_container_client(container= container_name) 
+            files = os.listdir(path_dir)
+            filesToUpload = []
+            for file in files:
+                if(re.search(regex,file)):
+                    filesToUpload.append(file)
+            for file in filesToUpload:
+                filepath = path_dir+"/"+file
+                uri = uri_base+"/"+file
+                blob_client = blob_service_client.get_blob_client(container=container_name, blob=uri)
+                # Upload the created file
+                with open(filepath, "rb") as data:
+                    blob_client.upload_blob(data)
+                    print("Uploaded: " + uri)
+                    
+     
         
